@@ -24,18 +24,23 @@
 #ifndef _RHONABWY_CFG_H_
 #define _RHONABWY_CFG_H_
 
-#define RHONABWY_VERSION 0.9.999
-#define RHONABWY_VERSION_STR "0.9.999"
+#define RHONABWY_VERSION 1.0.0
+#define RHONABWY_VERSION_STR "1.0.0"
 
-#define RHONABWY_VERSION_MAJOR 0
-#define RHONABWY_VERSION_MINOR 9
-#define RHONABWY_VERSION_PATCH 999
+#define RHONABWY_VERSION_MAJOR 1
+#define RHONABWY_VERSION_MINOR 0
+#define RHONABWY_VERSION_PATCH 0
 
 #define RHONABWY_VERSION_NUMBER ((RHONABWY_VERSION_MAJOR << 16) | (RHONABWY_VERSION_MINOR << 8) | (RHONABWY_VERSION_PATCH << 0))
 
+#define RHONABWY_CHECK_VERSION(major,minor,patch)                        \
+  (RHONABWY_VERSION_MAJOR > (major) ||                                    \
+   (RHONABWY_VERSION_MAJOR == (major) && RHONABWY_VERSION_MINOR > (minor)) || \
+   (RHONABWY_VERSION_MAJOR == (major) && RHONABWY_VERSION_MINOR == (minor) && \
+    RHONABWY_VERSION_PATCH >= (patch)))
+
 #define NETTLE_VERSION_NUMBER ((NETTLE_VERSION_MAJOR << 16) | (NETTLE_VERSION_MINOR << 8))
 
-/* #undef R_ECDH_ENABLED */
-#define R_WITH_ULFIUS
+#define R_WITH_CURL
 
 #endif /* _RHONABWY_CFG_H_ */
